@@ -1,12 +1,15 @@
 #' Leave-One-Out Cross-Validation
 #'
-#' Leave-one-out (LOO) cross-validation uses one data point in the original set as the assessment data and all other data points as the analysis set. A LOO resampling set has as many resamples as rows in the original data set.
-#'
+#' Leave-one-out (LOO) cross-validation uses one data point in the original
+#'  set as the assessment data and all other data points as the analysis set. A
+#'  LOO resampling set has as many resamples as rows in the original data set.
 #' @inheritParams vfold_cv
-#' @return  An tibble with classes `loo_cv`, `rset`, `tbl_df`, `tbl`, and `data.frame`. The results include a column for the data split objects and one column called `id` that has a character string with the resample identifier.
+#' @return An tibble with classes `loo_cv`, `rset`, `tbl_df`, `tbl`, and
+#'  `data.frame`. The results include a column for the data split objects and
+#'  one column called `id` that has a character string with the resample
+#'  identifier.
 #' @examples
 #' loo_cv(mtcars)
-#' @importFrom purrr map
 #' @export
 loo_cv <- function(data, ...) {
   split_objs <- vfold_splits(data = data, v = nrow(data))
@@ -28,7 +31,7 @@ loo_cv <- function(data, ...) {
 print.loo_cv <- function(x, ...) {
   cat("#", pretty(x), "\n")
   class(x) <- class(x)[!(class(x) %in% c("loo_cv", "rset"))]
-  print(x)
+  print(x, ...)
 }
 
 change_class <- function(x) {
