@@ -4,9 +4,9 @@
 #'  replacement) of the original data set to be used for analysis. All other
 #'  data points are added to the assessment set.
 #' @details The `strata` argument causes the random sampling to be conducted
-#'  *within the stratification variable*. The can help ensure that the number of
+#'  *within the stratification variable*. This can help ensure that the number of
 #'  data points in the analysis data is equivalent to the proportions in the
-#'  original data set.
+#'  original data set. (Strata below 10% of the total are pooled together.)
 #' @inheritParams vfold_cv
 #' @param prop The proportion of data to be retained for modeling/analysis.
 #' @param times The number of times to repeat the sampling.
@@ -99,10 +99,10 @@ mc_splits <- function(data, prop = 3/4, times = 25, strata = NULL, breaks = 4) {
     stratas <- tibble::tibble(idx = 1:n,
                               strata = make_strata(getElement(data, strata),
                                                    breaks = breaks))
-    stratas <- split(stratas, stratas$strata)
+    stratas <- split_unnamed(stratas, stratas$strata)
     stratas <-
       purrr::map_df(stratas, strat_sample, prop = prop, times = times)
-    indices <- split(stratas$idx, stratas$rs_id)
+    indices <- split_unnamed(stratas$idx, stratas$rs_id)
   }
   indices <- lapply(indices, mc_complement, n = n)
   split_objs <-
